#!/bin/sh
# ------------------------------------------------------------------------------
# Copyright (c) 1996-2000 Inprise Corporation.  All Rights Reserved.
# ------------------------------------------------------------------------------
#
# A set of functions used to parse a configuration file.
# --PC

JBUILDER_DOT_DIR=".jbuilder5"

# Set the LD_LIBRARY_PATH according to the processor architecture
function setArchitecture
{
  osName=`uname`

  if [ "$osName" = "SunOS" ]; then
    arch=`uname -p`
  else
    # Otherwise we assume uname uses the same option of good ol' Linux
    arch=`uname -m`
  fi
  if echo $arch | grep 'i.86' > /dev/null ; then
    arch='i386'
  fi
  if [ -z $LD_LIBRARY_PATH ]; then
    LD_LIBRARY_PATH=`dirname $jvm`"/../lib/$arch"
  else 
    LD_LIBRARY_PATH="$LD_LIBRARY_PATH:"`dirname $jvm`"/../lib/$arch"
  fi
  export LD_LIBRARY_PATH
}

# Generic call to extract the value of a keyword.
# @param $1 The keyword to check
function getKeywordValue
{
  keyWord="$1"

  value=`grep "^$keyWord" $cfgFile | sed "s/$keyWord //"`
}

function include
{
  local includeFile=$1
  # Search in the current dire. first
  if [ -f $includeFile ]; then
    . "./$includeFile"
  else
    . "$cfgFileDir/$includeFile"
  fi
}

# Retrieves the value of the "mainclass" keyword in the config file
function mainclass
{
  mainClass="$1"
}

# Retrieves all the "vmparams" statements and concatenate them in une variable
function vmparam
{
  vmArgs="$vmArgs $1"
}

# Retrieves the env statements and creates Java property commands to
# pass the variables to the JVM

function copyenv
{
  local tmp='envVars="$envVars "-Dborland.copyenv.$1=$'$1
  eval $tmp
}


# Retrieves the value of the bootpath statement
function addbootpath
{
  local jarFile
  if [ -z "$bootPath" ]; then
     bootPath="-Xbootclasspath/p"
  fi
  if [ -f $1 ]; then
    jarFile=$1
  else
    jarFile="$cfgFileDir/$1"
  fi
  bootPath="$bootPath:$jarFile"
}

# Retrieves the list of all jar files according to the "addjar" statements
# in the config file
function addjars
{
  local jarDir=$1
  
#  if [ ! -d $jarDir ]; then
#    jarDir="$cfgFileDir/$jarDir"
#  fi

  # If the path is a local one "jumping" up via the ".." notation then
  # we simply append it to the source path
  case $jarDir in
    ..*) 
      jarDir="$cfgFileDir/$jarDir"
      ;;
  esac
  for file in `ls -1 $jarDir/*.jar 2> /dev/null`; do
    if [ -z "$CLASSPATH" ]; then
      CLASSPATH="$file"
    else 
      CLASSPATH="$CLASSPATH:$file"
    fi
  done
}

# Retrieves the location of the JVM based on the "javapath" statement
function javapath
{
  jvm="$1"
}

# Retrieves the value of the "addpath" statement
function addpath
{ 
  if [ -z "$CLASSPATH" ]; then
    CLASSPATH=$1
  else
    CLASSPATH="$CLASSPATH:$1"
  fi 

}


# Directive to include all *.config files from a directory
function includedir
{
  local incdir=$1
  local cfgfile
  local fileList

#  if [ ! -d "$incdir" ]; then
#    incdir="$cfgFileDir/incdir"
#  fi

  case $incdir in
    ..*)
      incdir="$cfgFileDir/$incdir"
      ;;
  esac
  fileList=`ls $incdir/*.config > /dev/null 2>&1`
  if [ $? -gt 0 ]; then
    return
  fi 
  fileList="$incdir/*.config"
  for cfgfile in $fileList ; do
    parseConfiguration $cfgfile
  done
}

# Adds the JBuilder/JDatastore icons to the user's desktop the
# first time the program runs.
function checkDesktop
{
  local JBVersion="5.0"
  local gnomeDesktop="$HOME/.gnome-desktop"
  local kdeDesktop="$HOME/Desktop"
  local jbHomeDir="$HOME/$JBUILDER_DOT_DIR"
  local flagFile="$jbHomeDir/jbuilder$JBVersion.icons"

  local dname=`dirname $0`
  case $dname in
    .)
      local myPWD=`pwd`
      cd ..
      dname=`pwd`
      cd $myPWD
      ;; 
    ./*)
      local myPWD=`pwd`
      cd "$dname/.."
      dname=`pwd`
      cd $myPWD
      ;;
    /*)
      local myPWD=`pwd`
      cd "$dname/.."
      dname=`pwd`
      cd $myPWD
      ;;
      
  esac
  if [ ! -d $jbHomeDir ]; then
    mkdir $jbHomeDir
  fi

  if [ ! -f $flagFile ]; then
#    local dname=`pwd`
#    dname=`dirname $dname`
    eval $jvm -jar "$dname/lib/linuxDesktopConfigurator.jar" "$dname" ask
  fi
  echo "Desktop settings created for this user. Remove this file to create icons and file associations again." > $flagFile
}

# Parse the configuration file. If there's a jdk.config it will be parsed as well.
function parseConfiguration
{
  cfgFile=$1
  cfgFileDir=`dirname $1`

  . $cfgFile
  setArchitecture
}

#
# Give a chance to a Java program to use the environemnt exporting all the
# strings to a text file and passing the name of the file aas a Java Property
#
function exportenv
{
  local JBENV_FILE=$HOME/$JBUILDER_DOT_DIR/jbenv.txt
  $SDIR/dumpenv > $JBENV_FILE
  vmArgs="$vmArgs -Dborland.exportenv=$JBENV_FILE"
}
